
History
-------
0.4.11dev1 (17.07.2013)
+++++++++++++++++++++++
  - Utilisation comutation added (Allan)

0.4.10dev1 (8.7.2013)
+++++++++++++++++++++
 - --generate_dots generates now also the whole state space

0.4.9dev1 (26.05.2013)
++++++++++++++++++++++
 - Added custom exceptions
 - pypepa can be now tested (nose or pytest2)
 - first travis integration attempt

0.4.8dev1 (15.6.2013)
+++++++++++++++++++++
 - Added some verification of model sanity, redundant rate definitions, etc
 - Rate can be defined by mathematical expressions with variables, e.g. a= b*3+5
 - All exit(1) calls changed to exceptions in pypepa lib

0.4.7dev (6.6.2013)
+++++++++++++++++++

 - Fixes of some of typos
 - Many changes to setup.py (requirements work at last)

0.4.2dev (05.06.2013)
+++++++++++++++++++

 - Merge with Allan Clark's pull request providing better API
 - Changed name from libpepa to pypepa where possible  
 - First package version, for now only for dev branch 
 - pypepa cli moved to pypepa.cli for a better packaging
 
 
